//
//  FVColorMenuView.h
//  colormenu
//
//  Created by Adam Maxwell on 02/20/08.
/*
 This software is Copyright (c) 2008-2009
 Adam Maxwell. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 - Redistributions of source code must retain the above copyright
 notice, this list of conditions and the following disclaimer.
 
 - Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions and the following disclaimer in
 the documentation and/or other materials provided with the
 distribution.
 
 - Neither the name of Adam Maxwell nor the names of any
 contributors may be used to endorse or promote products derived
 from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Cocoa/Cocoa.h>

@class FVColorMenuMatrix;

/*
 
 FVColorMenuView provides an NSView subclass that is a close approximation of the Finder label color control.  Presently it's only available directly in code, but is easy to set up in code:

 NSMenuItem *anItem = [[NSMenuItem allocWithZone:[NSMenu menuZone]] initWithTitle:@"Finder Label" 
                                                                           action:@selector(changeFinderLabel:)
                                                                    keyEquivalent:@""];
 FVColorMenuView *menuView = [FVColorMenuView menuView];
 // target will be first responder
 // Target must implement -(NSArray *)selectedFinderLabels to return the selected Finder label(s).
 
 [menuView setTarget:nil]; 
 [menuView setAction:@selector(changeFinderLabel:)];
 [anItem setView:menuView];
 // add anItem to a menu
 
 */
@interface FVColorMenuView : NSControl
{
    IBOutlet FVColorMenuMatrix *_matrix;
    IBOutlet NSTextField       *_labelField;
    IBOutlet NSTextField       *_labelNameField;
}

/* This is the primary interface for returning a new menu view.  It handles loading UI elements from the nib and setting up connections. Do not use initWithFrame: to create a new instance. */
+ (FVColorMenuView *)menuView;

/* For programmatic selection changes. */
- (void)selectLabel:(NSUInteger)label;

@end

/*
 
 The following undocumented classes are only declared for IB.  Do not rely on them or use them outside the FVColorMenuView implementation.

 */
@interface FVColorMenuCell : NSButtonCell
@end

@interface FVColorMenuMatrix : NSMatrix
{
    NSInteger _boxedRow;
    NSInteger _boxedColumn;
	NSArray	*_selectedLabels;
}
- (NSString *)boxedLabelName;

@end


@interface FVFinderLabel

+ (void)drawFinderLabel:(NSUInteger)label inRect:(CGRect)rect ofContext:(CGContextRef)context flipped:(BOOL)isFlipped roundEnds:(BOOL)flag;
+ (void)drawFinderLabel:(NSUInteger)label inRect:(NSRect)rect roundEnds:(BOOL)flag;
+ (NSString *)nameForLabel:(NSUInteger)label;

@end











